#
# spec file for package gssproxy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gssproxy
Version:        0.8.4
Release:        2.9
Summary:        Daemon for managing gss-api requests
License:        MIT
Group:          Productivity/Networking/System
URL:            https://github.com/gssapi/gssproxy 
Source0:        https://github.com/gssapi/gssproxy/releases/download/v%{version}/gssproxy-%{version}.tar.gz
Patch0:	harden_gssproxy.service.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  krb5-client
BuildRequires:  krb5-plugin-kdb-ldap
BuildRequires:  libtool
BuildRequires:  openldap2
BuildRequires:  openldap2-client
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  systemd-rpm-macros
BuildRequires:  valgrind
BuildRequires:  pkgconfig(ini_config) >= 1.2.0
BuildRequires:  pkgconfig(krb5-gssapi) >= 1.12.0
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(nss_wrapper)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(socket_wrapper)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  user(nobody)
%{?systemd_requires}
%if 0%{?suse_version} > 1315
# in earlier versions, libverto is in krb5-devel
BuildRequires:  pkgconfig(libverto) >= 0.2.2
%endif

%description
gssproxy allows the complexity of GSS security negotiation
to be centrallized.  It is particularly useful to keep this out
of kernel space, so that CIPFS, NFS, AFS etc can use GSS-API without
complexity in the kernel.

Using it also improves isolation and privilege separation, so that
HTTP servers, for example, can use GSS-API without needing to access
keys directly.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fvi
%configure
make %{?_smp_mflags}
make -j1 test_proxymech

%install
%make_install
rm -f %{buildroot}%{_libdir}/gssproxy/proxymech.la
ln -s service %{buildroot}%{_sbindir}/rcgssproxy
install -D -m 644 examples/gssproxy.conf %{buildroot}%{_sysconfdir}/gssproxy/gssproxy.conf
install -d -m 700 %{buildroot}%{_localstatedir}/lib/gssproxy/rcache
install -D -m 644 examples/24-nfs-server.conf %{buildroot}%{_sysconfdir}/gssproxy/24-nfs-server.conf

%check
make %{?_smp_mflags} check

%pre
%service_add_pre gssproxy.service

%post
%service_add_post gssproxy.service

%preun
%service_del_preun gssproxy.service

%postun
%service_del_postun gssproxy.service

%files
%license COPYING
%{_sbindir}/gssproxy
%{_sbindir}/rcgssproxy
%dir %{_libdir}/gssproxy
%{_libdir}/gssproxy/proxymech.so
%dir %{_localstatedir}/lib/gssproxy
%dir %{_localstatedir}/lib/gssproxy/rcache
%{_unitdir}/gssproxy.service
%{_mandir}/man5/gssproxy.conf.5%{?ext_man}
%{_mandir}/man8/gssproxy-mech.8%{?ext_man}
%{_mandir}/man8/gssproxy.8%{?ext_man}
%dir %{_sysconfdir}/gssproxy
%config %{_sysconfdir}/gssproxy/gssproxy.conf
%config %{_sysconfdir}/gssproxy/24-nfs-server.conf

%changelog
* Tue Sep 21 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_gssproxy.service.patch
* Tue Mar 16 2021 pgajdos@suse.com
- version update to 0.8.4
  see changelog at:
  https://github.com/gssapi/gssproxy/blob/main/docs/Releases/v0.8.4.md
* Tue Jan 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Replace system-user-nobody with user(nobody): be resilient to
  package name changes.
- Replace python3 BuildRequires with python3-base: make build dep
  chain quite a bit cheaper.
* Thu Apr 23 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.8.3:
  * various fixes
- Removed 0001-Fix-runtests.py.patch
* Thu Jul  4 2019 Samuel Cabrero <scabrero@suse.de>
- Fix paths in tests and replace python's f-string usage
- Test are passing in OBS, drop patch disable-failing-test.patch
- Added patches:
  * 0001-Fix-runtests.py.patch
- Removed patches:
  * disable-failing-test.patch
* Mon Jul  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to disable one test that fails in OBS only:
  * disable-failing-test.patch
* Wed May 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.8.2:
  * no actual changelog, many bugfixes and friends
- Remove no longer appplicable stuff:
  * 0001-Add-support-for-the-NO_CI_FLAG-credentials-option.REVERT
  * 0002-Add-test-to-check-setting-cred-options.REVERT
  * 0003-Include-header-for-writev.patch
  * gp_config.fix
- Remove localy created .pc files
* Sun Oct  8 2017 nfbrown@suse.com
- 0003-Include-header-for-writev.patch
  upstream patch to fix build error
* Mon Mar 20 2017 nfbrown@suse.com
- gssproxy.spec - lots of tidy up, particularly using
  pkgconfig() for BuildRequires
* Thu Mar  9 2017 nfbrown@suse.com
- Initial check-in of version 0.7.0
  gssproxy is needed on the NFS server if krb5 is used for NFS
  authentication using an AD directory server.
  /etc/krb5.conf may need "auth_to_local = RULE:[1:$1@$0]" on
  the "realms" section when "winbind" is used for nsswitch.conf.
  (bsc#1024309)(FATE#322526)
- gp_config.fix
  0001-Add-support-for-the-NO_CI_FLAG-credentials-option.REVERT
  0002-Add-test-to-check-setting-cred-options.REVERT
  Conditionally allow compilation on older releases.
